==> green-core-1.70.1.tgz: package/components/mask/mask.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { html } from "lit/static-html.js";
import { tokens } from "../../tokens.style";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property";
import { gdsCustomElement } from "../../utils/helpers/custom-element-scoping";
import { GdsFlex } from "../flex/flex.component";
import MaskCSS from "./mask.style";
let GdsMask = class extends GdsFlex {
  constructor() {
    super();
    this["mask-size"] = "cover";
    this["mask-repeat"] = "no-repeat";
    this["mask-position"] = "center";
    this.position = "relative";
    this.inset = "0";
  }
  render() {
    return html`<div part="mask"></div>
      <div part="content"><slot></slot></div>`;
  }
};
GdsMask.styles = [tokens, MaskCSS];
__decorateClass([
  styleExpressionProperty({
    selector: '[part="mask"]',
    valueTemplate: (v) => {
      const [direction] = v.split("/");
      return `linear-gradient(to ${direction}, rgba(0, 0, 0, 1) 20%, rgba(0, 0, 0, 0) 100%)`;
    }
  })
], GdsMask.prototype, "mask-image", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: '[part="mask"]'
  })
], GdsMask.prototype, "mask-size", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: '[part="mask"]'
  })
], GdsMask.prototype, "mask-repeat", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: '[part="mask"]'
  })
], GdsMask.prototype, "mask-position", 2);
__decorateClass([
  styleExpressionProperty({
    selector: '[part="mask"]',
    valueTemplate: function(v) {
      const [backgroundColor, backgroundColorAlpha] = v.split("/");
      const background = backgroundColorAlpha ? `color-mix(in srgb, var(--gds-color-${"l" + this.level}-background-${backgroundColor}) ${parseFloat(backgroundColorAlpha) * 100}%, transparent 0%)` : `var(--gds-color-${"l" + this.level}-background-${backgroundColor})`;
      return background;
    }
  })
], GdsMask.prototype, "background-color", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: '[part="mask"]'
  })
], GdsMask.prototype, "backdrop-filter", 2);
GdsMask = __decorateClass([
  gdsCustomElement("gds-mask")
], GdsMask);
export {
  GdsMask
};

==> green-core-1.71.0.tgz: package/components/mask/mask.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { html } from "lit/static-html.js";
import { tokens } from "../../tokens.style";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property.js";
import { gdsCustomElement } from "../../utils/helpers/custom-element-scoping.js";
import { GdsFlex } from "../flex/flex.component.js";
import MaskCSS from "./mask.style";
let GdsMask = class extends GdsFlex {
  constructor() {
    super();
    this["mask-size"] = "cover";
    this["mask-repeat"] = "no-repeat";
    this["mask-position"] = "center";
    this.position = "relative";
    this.inset = "0";
  }
  render() {
    return html`<div part="mask"></div>
      <div part="content"><slot></slot></div>`;
  }
};
GdsMask.styles = [tokens, MaskCSS];
__decorateClass([
  styleExpressionProperty({
    selector: '[part="mask"]',
    valueTemplate: (v) => {
      const [direction] = v.split("/");
      return `linear-gradient(to ${direction}, rgba(0, 0, 0, 1) 20%, rgba(0, 0, 0, 0) 100%)`;
    }
  })
], GdsMask.prototype, "mask-image", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: '[part="mask"]'
  })
], GdsMask.prototype, "mask-size", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: '[part="mask"]'
  })
], GdsMask.prototype, "mask-repeat", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: '[part="mask"]'
  })
], GdsMask.prototype, "mask-position", 2);
__decorateClass([
  styleExpressionProperty({
    selector: '[part="mask"]',
    valueTemplate: function(v) {
      const [backgroundColor, backgroundColorAlpha] = v.split("/");
      const background = backgroundColorAlpha ? `color-mix(in srgb, var(--gds-color-${"l" + this.level}-background-${backgroundColor}) ${parseFloat(backgroundColorAlpha) * 100}%, transparent 0%)` : `var(--gds-color-${"l" + this.level}-background-${backgroundColor})`;
      return background;
    }
  })
], GdsMask.prototype, "background-color", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: '[part="mask"]'
  })
], GdsMask.prototype, "backdrop-filter", 2);
GdsMask = __decorateClass([
  gdsCustomElement("gds-mask")
], GdsMask);
export {
  GdsMask
};
